searchNodes=[{"doc":"Liquid template renderer for Elixir with a goal of 100% compatibility with the Liquid gem by Shopify. Basic Usage iex&gt; {:ok, template_ast} = Liquex.parse(&quot;Hello {{ name }}!&quot;) iex&gt; context = Liquex.Context.new(%{&quot;name&quot; =&gt; &quot;World&quot;}) iex&gt; {content, _context} = Liquex.render(template_ast, context) iex&gt; content |&gt; to_string() &quot;Hello World!&quot; Supported features Currently, all standard Liquid tags, filters, and types are fully supported. Liquex can be considered a drop in replacement of the Liquid gem, but in Elixir. There is a caveat that must be noted: Whitespace control is partially supported. Whitespace control is only partially supported. Whitespace is successfully removed after -%} and -}} tags. However, whitespace isn&#39;t removed from the left side yet, before {%- and {{-. This is because we&#39;re using NimbleParsec which does not support greedy matches. Instead, we will need to do post processing to properly remove spaces. As whitespace control is deemed of low importance for most applications, this has not been prioritized. Custom filters Liquex contains the full suite of standard Liquid filters, but you may find that there are still filters that you may want to add. Liquex supports adding your own custom filters to the render pipeline. When creating the context for the renderer, set the filter module to your own module. defmodule CustomFilter do # Import all the standard liquid filters use Liquex.Filter def scream(value, _), do: String.upcase(value) &lt;&gt; &quot;!&quot; end context = %Liquex.Context{filter_module: CustomFilter}, {:ok, template_ast} = Liquex.parse(&quot;{{&#39;Hello World&#39; | scream}}&quot;, {result, _} = Liquex.render(template_ast, context) result |&gt; to_string() iex&gt; &quot;HELLO WORLD!&quot; Custom tags One of the strong points for Liquex is that the tag parser can be extended to support non-standard tags. For example, Liquid used internally for the Shopify site includes a large range of tags that are not supported by the base Ruby gem. These tags could also be added to Liquex by extending the liquid parser. defmodule CustomTag do import NimbleParsec alias Liquex.Parser.Base # Parse &lt;&lt;Custom Tag&gt;&gt; def custom_tag(combinator \\\\ empty()) do text = lookahead_not(string(&quot;&gt;&gt;&quot;)) |&gt; utf8_char([]) |&gt; times(min: 1) |&gt; reduce({Kernel, :to_string, []}) |&gt; tag(:text) combinator |&gt; ignore(string(&quot;&lt;&lt;&quot;)) |&gt; optional(text) |&gt; ignore(string(&quot;&gt;&gt;&quot;)) |&gt; tag(:custom_tag) end def element(combinator \\\\ empty()) do # Add the `custom_tag/1` parsing function to the supported element tag list combinator |&gt; choice([custom_tag(), Base.base_element()]) end end defmodule CustomParser do @moduledoc false import NimbleParsec defcombinatorp(:document, repeat(CustomTag.element())) defparsec(:parse, parsec(:document) |&gt; eos()) end iex&gt; Liquex.parse(&quot;&lt;&lt;Hello World!&gt;&gt;&quot;, CustomParser) iex&gt; {:ok, [custom_tag: [text: [&quot;Hello World!&quot;]]]} Custom renderer In many cases, if you are building custom tags for your Liquid documents, you probably want to use a custom renderer. Just like the custom filters, you add your module to the context object. defmodule CustomRenderer do def render({:custom_tag, contents}, context) do {result, context} = Liquex.render(contents, context) {[&quot;Custom Tag: &quot;, result], context} end end context = %Liquex.Context{render_module: CustomRenderer} {:ok, document} = Liquex.parse(&quot;&lt;&lt;Hello World!&gt;&gt;&quot;, CustomParser) {result, _} = Liquex.render(document, context) result |&gt; to_string() iex&gt; &quot;Custom Tag: Hello World!&quot; Installation Add the package to your mix.exs file. def deps do [{:liquex, &quot;~&gt; 0.1.1&quot;}] end","ref":"Liquex.html","title":"Liquex","type":"module"},{"doc":"Parses a liquid template string using the given parser. Returns a liquid AST document or the parser error","ref":"Liquex.html#parse/2","title":"Liquex.parse/2","type":"function"},{"doc":"Renders a Liquid AST document into an iolist A context is given to handle temporary contextual information for this render.","ref":"Liquex.html#render/2","title":"Liquex.render/2","type":"function"},{"doc":"","ref":"Liquex.html#t:document_t/0","title":"Liquex.document_t/0","type":"type"},{"doc":"Stores contextual information for the parser","ref":"Liquex.Context.html","title":"Liquex.Context","type":"module"},{"doc":"Assign a new variable to the context Set a variable named key with the given value in the current context","ref":"Liquex.Context.html#assign/3","title":"Liquex.Context.assign/3","type":"function"},{"doc":"Create a new Context.t using predefined variables map Returns a new, initialized context object","ref":"Liquex.Context.html#new/1","title":"Liquex.Context.new/1","type":"function"},{"doc":"","ref":"Liquex.Context.html#t:t/0","title":"Liquex.Context.t/0","type":"type"},{"doc":"Contains all the basic filters for Liquid","ref":"Liquex.Filter.html","title":"Liquex.Filter","type":"module"},{"doc":"Returns the absolute value of value. Examples iex&gt; Liquex.Filter.abs(-1, %{}) 1 iex&gt; Liquex.Filter.abs(1, %{}) 1 iex&gt; Liquex.Filter.abs(&quot;-1.1&quot;, %{}) 1.1","ref":"Liquex.Filter.html#abs/2","title":"Liquex.Filter.abs/2","type":"function"},{"doc":"Appends text to the end of value Examples iex&gt; Liquex.Filter.append(&quot;myfile&quot;, &quot;.html&quot;, %{}) &quot;myfile.html&quot;","ref":"Liquex.Filter.html#append/3","title":"Liquex.Filter.append/3","type":"function"},{"doc":"","ref":"Liquex.Filter.html#apply/4","title":"Liquex.Filter.apply/4","type":"function"},{"doc":"Sets a minimum value Examples iex&gt; Liquex.Filter.at_least(3, 5, %{}) 5 iex&gt; Liquex.Filter.at_least(5, 3, %{}) 5","ref":"Liquex.Filter.html#at_least/3","title":"Liquex.Filter.at_least/3","type":"function"},{"doc":"Sets a maximum value Examples iex&gt; Liquex.Filter.at_most(4, 5, %{}) 4 iex&gt; Liquex.Filter.at_most(4, 3, %{}) 3","ref":"Liquex.Filter.html#at_most/3","title":"Liquex.Filter.at_most/3","type":"function"},{"doc":"Capitalizes a string Examples iex&gt; Liquex.Filter.capitalize(&quot;title&quot;, %{}) &quot;Title&quot; iex&gt; Liquex.Filter.capitalize(&quot;my great title&quot;, %{}) &quot;My great title&quot;","ref":"Liquex.Filter.html#capitalize/2","title":"Liquex.Filter.capitalize/2","type":"function"},{"doc":"Rounds value up to the nearest whole number. Liquid tries to convert the input to a number before the filter is applied. Examples iex&gt; Liquex.Filter.ceil(1.2, %{}) 2 iex&gt; Liquex.Filter.ceil(2.0, %{}) 2 iex&gt; Liquex.Filter.ceil(183.357, %{}) 184 iex&gt; Liquex.Filter.ceil(&quot;3.5&quot;, %{}) 4","ref":"Liquex.Filter.html#ceil/2","title":"Liquex.Filter.ceil/2","type":"function"},{"doc":"Removes any nil values from an array. Examples iex&gt; Liquex.Filter.compact([1, 2, nil, 3], %{}) [1,2,3] iex&gt; Liquex.Filter.compact([1, 2, 3], %{}) [1,2,3]","ref":"Liquex.Filter.html#compact/2","title":"Liquex.Filter.compact/2","type":"function"},{"doc":"Concatenates (joins together) multiple arrays. The resulting array contains all the items Examples iex&gt; Liquex.Filter.concat([1,2], [3,4], %{}) [1,2,3,4]","ref":"Liquex.Filter.html#concat/3","title":"Liquex.Filter.concat/3","type":"function"},{"doc":"Converts value timestamp into another date format. The format for this syntax is the same as strftime. The input uses the same format as Ruby’s Time.parse. Examples iex&gt; Liquex.Filter.date(~D[2000-01-01], &quot;%m/%d/%Y&quot;, %{}) &quot;01/01/2000&quot; iex&gt; Liquex.Filter.date(&quot;2000-01-01&quot;, &quot;%m/%d/%Y&quot;, %{}) &quot;01/01/2000&quot; iex&gt; Liquex.Filter.date(&quot;January 1, 2000&quot;, &quot;%m/%d/%Y&quot;, %{}) &quot;01/01/2000&quot; iex&gt; Liquex.Filter.date(&quot;1/2/2000&quot;, &quot;%m/%d/%Y&quot;, %{}) &quot;01/02/2000&quot; iex&gt; Liquex.Filter.date(&quot;March 14, 2016&quot;, &quot;%b %d, %y&quot;, %{}) &quot;Mar 14, 16&quot;","ref":"Liquex.Filter.html#date/3","title":"Liquex.Filter.date/3","type":"function"},{"doc":"Allows you to specify a fallback in case a value doesn’t exist. default will show its value if the left side is nil, false, or empty. Examples iex&gt; Liquex.Filter.default(&quot;1.99&quot;, &quot;2.99&quot;, %{}) &quot;1.99&quot; iex&gt; Liquex.Filter.default(&quot;&quot;, &quot;2.99&quot;, %{}) &quot;2.99&quot;","ref":"Liquex.Filter.html#default/3","title":"Liquex.Filter.default/3","type":"function"},{"doc":"Divides a number by another number. Examples The result is rounded down to the nearest integer (that is, the floor) if the divisor is an integer. iex&gt; Liquex.Filter.divided_by(16, 4, %{}) 4 iex&gt; Liquex.Filter.divided_by(5, 3, %{}) 1 iex&gt; Liquex.Filter.divided_by(20, 7.0, %{}) 2.857142857142857","ref":"Liquex.Filter.html#divided_by/3","title":"Liquex.Filter.divided_by/3","type":"function"},{"doc":"Makes each character in a string lowercase. It has no effect on strings which are already all lowercase. Examples iex&gt; Liquex.Filter.downcase(&quot;Parker Moore&quot;, %{}) &quot;parker moore&quot; iex&gt; Liquex.Filter.downcase(&quot;apple&quot;, %{}) &quot;apple&quot;","ref":"Liquex.Filter.html#downcase/2","title":"Liquex.Filter.downcase/2","type":"function"},{"doc":"Escapes a string by replacing characters with escape sequences (so that the string can be used in a URL, for example). It doesn’t change strings that don’t have anything to escape. Examples iex&gt; Liquex.Filter.escape(&quot;Have you read &#39;James &amp; the Giant Peach&#39;?&quot;, %{}) &quot;Have you read &amp;apos;James &amp;amp; the Giant Peach&amp;apos;?&quot; iex&gt; Liquex.Filter.escape(&quot;Tetsuro Takara&quot;, %{}) &quot;Tetsuro Takara&quot;","ref":"Liquex.Filter.html#escape/2","title":"Liquex.Filter.escape/2","type":"function"},{"doc":"Escapes a string by replacing characters with escape sequences (so that the string can be used in a URL, for example). It doesn’t change strings that don’t have anything to escape. Examples iex&gt; Liquex.Filter.escape_once(&quot;1 &amp;lt; 2 &amp;amp; 3&quot;, %{}) &quot;1 &amp;lt; 2 &amp;amp; 3&quot;","ref":"Liquex.Filter.html#escape_once/2","title":"Liquex.Filter.escape_once/2","type":"function"},{"doc":"Returns the first item of an array. Examples iex&gt; Liquex.Filter.first([1, 2, 3], %{}) 1 iex&gt; Liquex.Filter.first([], %{}) nil","ref":"Liquex.Filter.html#first/2","title":"Liquex.Filter.first/2","type":"function"},{"doc":"Rounds the input down to the nearest whole number. Liquid tries to convert the input to a number before the filter is applied. Examples iex&gt; Liquex.Filter.floor(1.2, %{}) 1 iex&gt; Liquex.Filter.floor(2.0, %{}) 2","ref":"Liquex.Filter.html#floor/2","title":"Liquex.Filter.floor/2","type":"function"},{"doc":"Combines the items in values into a single string using joiner as a separator. Examples iex&gt; Liquex.Filter.join(~w(John Paul George Ringo), &quot; and &quot;, %{}) &quot;John and Paul and George and Ringo&quot;","ref":"Liquex.Filter.html#join/3","title":"Liquex.Filter.join/3","type":"function"},{"doc":"Returns the last item of arr. Examples iex&gt; Liquex.Filter.last([1, 2, 3], %{}) 3 iex&gt; Liquex.Filter.first([], %{}) nil","ref":"Liquex.Filter.html#last/2","title":"Liquex.Filter.last/2","type":"function"},{"doc":"Removes all whitespace (tabs, spaces, and newlines) from the left side of a string. It does not affect spaces between words. Examples iex&gt; Liquex.Filter.lstrip(&quot; So much room for activities! &quot;, %{}) &quot;So much room for activities! &quot;","ref":"Liquex.Filter.html#lstrip/2","title":"Liquex.Filter.lstrip/2","type":"function"},{"doc":"Creates an array (arr) of values by extracting the values of a named property from another object (key). Examples iex&gt; Liquex.Filter.map([%{&quot;a&quot; =&gt; 1}, %{&quot;a&quot; =&gt; 2, &quot;b&quot; =&gt; 1}], &quot;a&quot;, %{}) [1, 2]","ref":"Liquex.Filter.html#map/3","title":"Liquex.Filter.map/3","type":"function"},{"doc":"Subtracts a number from another number. Examples iex&gt; Liquex.Filter.minus(4, 2, %{}) 2 iex&gt; Liquex.Filter.minus(183.357, 12, %{}) 171.357","ref":"Liquex.Filter.html#minus/3","title":"Liquex.Filter.minus/3","type":"function"},{"doc":"Subtracts a number from another number. Examples iex&gt; Liquex.Filter.modulo(3, 2, %{}) 1 iex&gt; Liquex.Filter.modulo(183.357, 12, %{}) 3.357","ref":"Liquex.Filter.html#modulo/3","title":"Liquex.Filter.modulo/3","type":"function"},{"doc":"Replaces every newline ( ) in a string with an HTML line break (). Examples iex&gt; Liquex.Filter.newline_to_br(&quot;\\nHello\\nthere\\n&quot;, %{}) &quot;&lt;br /&gt;\\nHello&lt;br /&gt;\\nthere&lt;br /&gt;\\n&quot;","ref":"Liquex.Filter.html#newline_to_br/2","title":"Liquex.Filter.newline_to_br/2","type":"function"},{"doc":"Adds a number to another number. Examples iex&gt; Liquex.Filter.plus(4, 2, %{}) 6 iex&gt; Liquex.Filter.plus(183.357, 12, %{}) 195.357","ref":"Liquex.Filter.html#plus/3","title":"Liquex.Filter.plus/3","type":"function"},{"doc":"Adds the specified string to the beginning of another string. Examples iex&gt; Liquex.Filter.prepend(&quot;apples, oranges, and bananas&quot;, &quot;Some fruit: &quot;, %{}) &quot;Some fruit: apples, oranges, and bananas&quot; iex&gt; Liquex.Filter.prepend(&quot;/index.html&quot;, &quot;example.com&quot;, %{}) &quot;example.com/index.html&quot;","ref":"Liquex.Filter.html#prepend/3","title":"Liquex.Filter.prepend/3","type":"function"},{"doc":"Removes every occurrence of the specified substring from a string. Examples iex&gt; Liquex.Filter.remove(&quot;I strained to see the train through the rain&quot;, &quot;rain&quot;, %{}) &quot;I sted to see the t through the &quot;","ref":"Liquex.Filter.html#remove/3","title":"Liquex.Filter.remove/3","type":"function"},{"doc":"Removes every occurrence of the specified substring from a string. Examples iex&gt; Liquex.Filter.remove_first(&quot;I strained to see the train through the rain&quot;, &quot;rain&quot;, %{}) &quot;I sted to see the train through the rain&quot;","ref":"Liquex.Filter.html#remove_first/3","title":"Liquex.Filter.remove_first/3","type":"function"},{"doc":"Replaces every occurrence of the first argument in a string with the second argument. Examples iex&gt; Liquex.Filter.replace(&quot;Take my protein pills and put my helmet on&quot;, &quot;my&quot;, &quot;your&quot;, %{}) &quot;Take your protein pills and put your helmet on&quot;","ref":"Liquex.Filter.html#replace/4","title":"Liquex.Filter.replace/4","type":"function"},{"doc":"Replaces only the first occurrence of the first argument in a string with the second argument. Examples iex&gt; Liquex.Filter.replace_first(&quot;Take my protein pills and put my helmet on&quot;, &quot;my&quot;, &quot;your&quot;, %{}) &quot;Take your protein pills and put my helmet on&quot;","ref":"Liquex.Filter.html#replace_first/4","title":"Liquex.Filter.replace_first/4","type":"function"},{"doc":"Reverses the order of the items in an array. reverse cannot reverse a string. Examples iex&gt; Liquex.Filter.reverse(~w(apples oranges peaches plums), %{}) [&quot;plums&quot;, &quot;peaches&quot;, &quot;oranges&quot;, &quot;apples&quot;]","ref":"Liquex.Filter.html#reverse/2","title":"Liquex.Filter.reverse/2","type":"function"},{"doc":"Rounds a number to the nearest integer or, if a number is passed as an argument, to that number of decimal places. Examples iex&gt; Liquex.Filter.round(1, %{}) 1 iex&gt; Liquex.Filter.round(1.2, %{}) 1 iex&gt; Liquex.Filter.round(2.7, %{}) 3 iex&gt; Liquex.Filter.round(183.357, 2, %{}) 183.36","ref":"Liquex.Filter.html#round/3","title":"Liquex.Filter.round/3","type":"function"},{"doc":"Removes all whitespace (tabs, spaces, and newlines) from the right side of a string. It does not affect spaces between words. Examples iex&gt; Liquex.Filter.rstrip(&quot; So much room for activities! &quot;, %{}) &quot; So much room for activities!&quot;","ref":"Liquex.Filter.html#rstrip/2","title":"Liquex.Filter.rstrip/2","type":"function"},{"doc":"Returns the number of characters in a string or the number of items in an array. Examples iex&gt; Liquex.Filter.size(&quot;Ground control to Major Tom.&quot;, %{}) 28 iex&gt; Liquex.Filter.size(~w(apples oranges peaches plums), %{}) 4","ref":"Liquex.Filter.html#size/2","title":"Liquex.Filter.size/2","type":"function"},{"doc":"Returns a substring of 1 character beginning at the index specified by the first argument. An optional second argument specifies the length of the substring to be returned. Examples iex&gt; Liquex.Filter.slice(&quot;Liquid&quot;, 0, %{}) &quot;L&quot; iex&gt; Liquex.Filter.slice(&quot;Liquid&quot;, 2, %{}) &quot;q&quot; iex&gt; Liquex.Filter.slice(&quot;Liquid&quot;, 2, 5, %{}) &quot;quid&quot; If the first argument is a negative number, the indices are counted from the end of the string: Examples iex&gt; Liquex.Filter.slice(&quot;Liquid&quot;, -3, 2, %{}) &quot;ui&quot;","ref":"Liquex.Filter.html#slice/4","title":"Liquex.Filter.slice/4","type":"function"},{"doc":"Sorts items in an array in case-sensitive order. Examples iex&gt; Liquex.Filter.sort([&quot;zebra&quot;, &quot;octopus&quot;, &quot;giraffe&quot;, &quot;Sally Snake&quot;], %{}) [&quot;Sally Snake&quot;, &quot;giraffe&quot;, &quot;octopus&quot;, &quot;zebra&quot;]","ref":"Liquex.Filter.html#sort/2","title":"Liquex.Filter.sort/2","type":"function"},{"doc":"Sorts items in an array in case-insensitive order. Examples iex&gt; Liquex.Filter.sort_natural([&quot;zebra&quot;, &quot;octopus&quot;, &quot;giraffe&quot;, &quot;Sally Snake&quot;], %{}) [&quot;giraffe&quot;, &quot;octopus&quot;, &quot;Sally Snake&quot;, &quot;zebra&quot;]","ref":"Liquex.Filter.html#sort_natural/2","title":"Liquex.Filter.sort_natural/2","type":"function"},{"doc":"Divides a string into an array using the argument as a separator. split is commonly used to convert comma-separated items from a string to an array. Examples iex&gt; Liquex.Filter.split(&quot;John, Paul, George, Ringo&quot;, &quot;, &quot;, %{}) [&quot;John&quot;, &quot;Paul&quot;, &quot;George&quot;, &quot;Ringo&quot;]","ref":"Liquex.Filter.html#split/3","title":"Liquex.Filter.split/3","type":"function"},{"doc":"Removes all whitespace (tabs, spaces, and newlines) from both the left and right side of a string. It does not affect spaces between words. Examples iex&gt; Liquex.Filter.strip(&quot; So much room for activities! &quot;, %{}) &quot;So much room for activities!&quot;","ref":"Liquex.Filter.html#strip/2","title":"Liquex.Filter.strip/2","type":"function"},{"doc":"Removes any HTML tags from a string. Examples iex&gt; Liquex.Filter.strip_html(&quot;Have &lt;em&gt;you&lt;/em&gt; read &lt;strong&gt;Ulysses&lt;/strong&gt;?&quot;, %{}) &quot;Have you read Ulysses?&quot;","ref":"Liquex.Filter.html#strip_html/2","title":"Liquex.Filter.strip_html/2","type":"function"},{"doc":"Removes any newline characters (line breaks) from a string. Examples iex&gt; Liquex.Filter.strip_newlines(&quot;Hello\\nthere&quot;, %{}) &quot;Hellothere&quot;","ref":"Liquex.Filter.html#strip_newlines/2","title":"Liquex.Filter.strip_newlines/2","type":"function"},{"doc":"Multiplies a number by another number. Examples iex&gt; Liquex.Filter.times(3, 4, %{}) 12 iex&gt; Liquex.Filter.times(24, 7, %{}) 168 iex&gt; Liquex.Filter.times(183.357, 12, %{}) 2200.284","ref":"Liquex.Filter.html#times/3","title":"Liquex.Filter.times/3","type":"function"},{"doc":"Shortens a string down to the number of characters passed as an argument. If the specified number of characters is less than the length of the string, an ellipsis (…) is appended to the string and is included in the character count. Examples iex&gt; Liquex.Filter.truncate(&quot;Ground control to Major Tom.&quot;, 20, %{}) &quot;Ground control to...&quot; iex&gt; Liquex.Filter.truncate(&quot;Ground control to Major Tom.&quot;, 25, &quot;, and so on&quot;, %{}) &quot;Ground control, and so on&quot; iex&gt; Liquex.Filter.truncate(&quot;Ground control to Major Tom.&quot;, 20, &quot;&quot;, %{}) &quot;Ground control to Ma&quot;","ref":"Liquex.Filter.html#truncate/4","title":"Liquex.Filter.truncate/4","type":"function"},{"doc":"Shortens a string down to the number of characters passed as an argument. If the specified number of characters is less than the length of the string, an ellipsis (…) is appended to the string and is included in the character count. Examples iex&gt; Liquex.Filter.truncatewords(&quot;Ground control to Major Tom.&quot;, 3, %{}) &quot;Ground control to...&quot; iex&gt; Liquex.Filter.truncatewords(&quot;Ground control to Major Tom.&quot;, 3, &quot;--&quot;, %{}) &quot;Ground control to--&quot; iex&gt; Liquex.Filter.truncatewords(&quot;Ground control to Major Tom.&quot;, 3, &quot;&quot;, %{}) &quot;Ground control to&quot;","ref":"Liquex.Filter.html#truncatewords/4","title":"Liquex.Filter.truncatewords/4","type":"function"},{"doc":"Removes any duplicate elements in an array. Examples iex&gt; Liquex.Filter.uniq(~w(ants bugs bees bugs ants), %{}) [&quot;ants&quot;, &quot;bugs&quot;, &quot;bees&quot;]","ref":"Liquex.Filter.html#uniq/2","title":"Liquex.Filter.uniq/2","type":"function"},{"doc":"Makes each character in a string uppercase. It has no effect on strings which are already all uppercase. Examples iex&gt; Liquex.Filter.upcase(&quot;Parker Moore&quot;, %{}) &quot;PARKER MOORE&quot; iex&gt; Liquex.Filter.upcase(&quot;APPLE&quot;, %{}) &quot;APPLE&quot;","ref":"Liquex.Filter.html#upcase/2","title":"Liquex.Filter.upcase/2","type":"function"},{"doc":"Decodes a string that has been encoded as a URL or by url_encode/2. Examples iex&gt; Liquex.Filter.url_decode(&quot;%27Stop%21%27+said+Fred&quot;, %{}) &quot;&#39;Stop!&#39; said Fred&quot;","ref":"Liquex.Filter.html#url_decode/2","title":"Liquex.Filter.url_decode/2","type":"function"},{"doc":"Decodes a string that has been encoded as a URL or by url_encode/2. Examples iex&gt; Liquex.Filter.url_encode(&quot;john@liquid.com&quot;, %{}) &quot;john%40liquid.com&quot; iex&gt; Liquex.Filter.url_encode(&quot;Tetsuro Takara&quot;, %{}) &quot;Tetsuro+Takara&quot;","ref":"Liquex.Filter.html#url_encode/2","title":"Liquex.Filter.url_encode/2","type":"function"},{"doc":"Creates an array including only the objects with a given property value, or any truthy value by default. Examples iex&gt; Liquex.Filter.where([%{&quot;b&quot; =&gt; 2}, %{&quot;b&quot; =&gt; 1}], &quot;b&quot;, 1, %{}) [%{&quot;b&quot; =&gt; 1}]","ref":"Liquex.Filter.html#where/4","title":"Liquex.Filter.where/4","type":"function"},{"doc":"Liquid parser","ref":"Liquex.Parser.html","title":"Liquex.Parser","type":"module"},{"doc":"Parses the given binary as parse. Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the parse (start position) as {line, column_on_line}. Options :line - the initial line, defaults to 1 :byte_offset - the initial byte offset, defaults to 0 :context - the initial context value. It will be converted to a map","ref":"Liquex.Parser.html#parse/2","title":"Liquex.Parser.parse/2","type":"function"},{"doc":"Liquex A Liquid template parser for Elixir. A goal for this project is to be 100% compatible with Shopify&#39;s Liquid templating engine for ruby.","ref":"readme.html","title":"Liquex","type":"extras"},{"doc":"The package is available in Hex and can be installed by adding liquex to your list of dependencies in mix.exs: def deps do [ {:liquex, &quot;~&gt; 0.2&quot;} ] end Documentation can be found at https://hexdocs.pm/liquex.","ref":"readme.html#installation","title":"Liquex - Installation","type":"extras"},{"doc":"Liquex&#39;s goal is 100% byte for byte compatibility with Liquid. The current state of the project can be seen here: Supported: [x] All tags [x] All filters [x] Objects and variables [x] Custom filter [x] Custom tags [x] Date processing parity with Ruby Not yet implemented [.] Full whitespace control [.] Full test suite using Liquid gem","ref":"readme.html#support","title":"Liquex - Support","type":"extras"}]